;+
; NAME:
;	Titles Display
; PURPOSE:
;	Changes title definitions, tick mark names, inteval
;	between ticks, number of tickmarks, style and
;	type of plot and plotting symbol.
; CATEGORY:
;	User interface
; CALLING SEQUENCE:
;	Titles_Display
; SIDE EFFECTS
;	The value of some system variables are changed, dependent
;	on the option chosen.
; 	Menus are used. On vt300 terminals, the
;	display is erased
;-
; MODIFICATION HISTORY:
;	Created in June 1991 by A.Csillaghy


PRO TicksChange, menuT, nr, tickName
 
tempStr = ''
IF StrLen(tickName(0) ) EQ 0 THEN $
  menuT(nr) = StrMid(menuT(nr),0,24) + 'System Defined' $
ELSE BEGIN
  i = 0 
  WHILE (tickName(i) NE '') AND (i  LT 29 ) DO BEGIN
    tempStr = tempStr + tickName(i) + ' '
    IF i LT 29 THEN i = i+1 
  ENDWHILE
ENDELSE 
menuT(nr) = StrMid(menuT(nr),0,24) + tempStr

END


PRO Intervals, menuT, nr, ticksInt

IF ticksInt EQ 0 THEN menuT(nr) = StrMid(menuT(nr),0,43) $
	 + 'System Defined' $
ELSE menuT(nr) = StrMid(menuT(nr),0,43) + StrTrim(ticksInt,2)

END


PRO MinorTicksNr, menuT, nr, minorNr

IF minorNr EQ 0 THEN $
	menuT(nr) = StrMid(menuT(nr),0,27) + 'System Defined' $
ELSE IF minorNr EQ -1 THEN $
	menuT(nr) = StrMid(menuT(nr),0,27)+'none' $
ELSE menuT(nr) = StrMid(menuT(nr),0,27) + StrTrim(minorNr-1,2)

END


PRO AxisStyle, menuT, nr, value

text = ''
IF (value AND 1B) EQ 1 THEN text = 'Exact'
IF (value AND 2B) EQ 2 THEN  text = text + ' Extended'
IF (value AND 4B) EQ 4 THEN text = text + ' None'
IF (value AND 8B) EQ 8 THEN text = text + ' No Box'

IF text EQ '' THEN $
	menuT(nr) = StrMid(menuT(nr),0,14)+'System Standard' $
ELSE menuT(nr) = StrMid(menuT(nr),0, 14) + text

END


PRO  AxisType, menuT, nr, value

IF value EQ 0 THEN menuT(nr) = StrMid(menuT(nr),0,13)+'Linear' $
ELSE menuT(nr) = StrMid(menuT(nr),0,13)+'Logaritmic'

END


PRO ModifXYTitle, dir

  title = ''
  Read,' Please give the new '+ dir +' title: ', title
  IF dir EQ 'X' THEN !x.title = title ELSE !y.title = title

END


PRO ModifTickDef, dir

i=0
Print,'Please give the new names of the '+dir+' tickmarks.'
Print,'They must be maximal 30.'
Print,'Type <return> to stop.'
Print,'Typing <return> for the first tick name will set the system ticks'
REPEAT BEGIN
  tickName  = ''
  Read,'Tick Name '+StrTrim(i+1,2)+': ', tickName
  IF dir EQ 'X' THEN  !x.tickname(i) = tickName $
  ELSE !y.tickname(i)  = tickName
  i = i+1
END UNTIL i EQ 30 OR StrLen(tickName) EQ 0
IF i EQ 1 THEN $
  IF dir EQ 'X' THEN  !x.tickname= '' $
  ELSE !y.tickname = ''

END


PRO ModifInterval, dir

  Print,'Please insert the new interval between major '+ $
	dir+' tick marks. '
  Print,'Type 0 for system definition'
  const = !x.ticks*( dir EQ 'X' ) + !y.ticks*( dir NE 'X' )
  Read_Test, 'Number of intervals:',const,interval
  IF dir EQ 'X' THEN !x.ticks = interval < 29 > 0 $
  ELSE !y.ticks = interval < 29 > 0

END ; Modif Interval

PRO ModifMarksNr, dir

  Print,'Please insert the new number of minor '+dir+' tick marks.'
  Print,'Type -1 for system definition.'
  Print,'Type 0 for no ticks.'
  Read_Test,'Number of minor tick marks: ',0, minor
  minor = -1 > minor < 50
  IF dir EQ 'X' THEN !x.minor = minor+1 ELSE !y.minor = minor+1

END ; modif marks nr


PRO ModifStyle, dir

  choice = General_Menu( $
	['Exact: axis range = data range', $
	'Extended: axis range = data range + 10 %', $
	'None: no axes drawn', $
	'No Box: axes only on the left or/and on the bottom', $
	'System Style: reset'],  $
 	'Choose the style of '+dir+ ' axis')
  IF choice LT 5 THEN $
    IF dir EQ 'X' THEN !x.style = !x.style OR BYTE(2^(choice-1)) $
    ELSE !y.style = !y.style OR BYTE(2^(choice-1)) $
  ELSE $
    IF dir EQ 'X' THEN !x.style = 0 $
    ELSE !y.style = 0

END


PRO TitlesFromPlot

  namesMenu = GetNames( )
  idx = General_Menu( namesMenu, 'Select one Plot ' )

   LoadPlot, namesMenu( idx-1 ), d,d,d,d, d,d, $
                    title,  xTitle,  yTitle, d,  d, $
 	lineStyle,  thick,  offset,  subTitle, overallQual

  !p.title = title
  !x.title = xTitle & !y.title = yTitle
  !p.subtitle = subTitle

END


PRO OverallDisplay

GetTitles, title, xTitle, yTitle, subtitle
!p.title = title & !p.subtitle = subtitle
!x.title = xTitle & !y.title = yTitle

mainMenuLength = 20
mainMenu = StrArr(mainMenuLength)

mainMenu(0) = 'Main Title: '+ !p.title 
mainMenu(1) = 'Subtitle: ' + !p.subtitle
mainMenu(2) = 'X Title: '+ !x.title
mainMenu(3) = 'Y Title: ' + !y.title
mainMenu(4) = 'Titles from a Plot ... '
mainMenu(5) = 'X Tickmarks Definition: '
mainMenu(6) = 'Y Tickmarks Definition: '
mainMenu(7) = 'Number of Intervals Between X Major Ticks: '
mainMenu(8) = 'Number of Intervals Between Y Major Ticks: '
mainMenu(9) = 'X Minor Tick Marks Number: '
mainMenu(10) = 'Y Minor Tick Marks Number: '
mainMenu(11) = 'X Axis Style: '
mainMenu(12) = 'Y Axis Style: '
mainMenu(13) = 'X Axis Type: '
mainMenu(14) = 'Y Axis Type: '
mainMenu(17) = 'Reset Offsets'
mainMenu(18) = 'Exit this Menu'
mainMenu(19) = 'Redisplay this Menu'

TicksChange, mainMenu, 5, !x.tickname
TicksChange, mainMenu, 6, !y.tickname

Intervals, mainMenu, 7, !x.ticks
Intervals, mainMenu, 8, !y.ticks

MinorTicksNr, mainMenu, 9, !x.minor
MinorTicksNr, mainMenu, 10, !y.minor

AxisStyle, mainMenu, 11, !x.style
AxisStyle, mainMenu, 12, !y.style

AxisType, mainMenu, 13, !x.type
AxisType, mainMenu, 14, !y.type

IF !p.font EQ 0 THEN mainMenu(15) = 'Hardware Font' $
ELSE IF !p.charsize NE 0 THEN $
	mainMenu(15) = 'Software Font, size '+ $
		StrTrim(!p.charsize,2) $
ELSE mainMenu(15) = 'Software  Font, System Defined'

hms = GetHMS()
IF hms EQ 1 THEN mainMenu(16) = 'X axis in Hours/Min/Sec.' $
ELSE mainMenu(16) = 'X Axis in Decimal Notation'

REPEAT BEGIN
  choice = General_Menu( mainMenu, $
	' Choose Attribute to Change')
  str = ''
  CASE choice OF
    1: BEGIN
          Read,'Please give the new title: ', str
          !p.title = str
          mainMenu(0) = StrMid(mainMenu(0),0,12) + str
        END
    2: BEGIN
          Read,'Please give the new subtitle: ', str
          !p.subtitle = str
          mainMenu(1) = StrMid(mainMenu(1),0,10)+str
         END
    3: BEGIN
          ModifXYTitle, 'X'
          mainMenu(2) = StrMid(mainMenu(2),0,9)+ !x.title
        END
    4: BEGIN
          ModifXYTitle, 'Y'
          mainMenu(3) = StrMid(mainMenu(3),0,9)+!y.title
        END
    5: BEGIN
           TitlesFromPlot
           mainMenu(0) = StrMid(mainMenu(0),0,12) + !p.title
           mainMenu(1) =  StrMid(mainMenu(1),0,10)+ !p.subtitle
           mainMenu(2) = StrMid(mainMenu(2),0,9)+ !x.title
           mainMenu(3) = StrMid(mainMenu(3),0,9)+!y.title
        END
    6: BEGIN
          ModifTickDef, 'X'
          TicksChange,mainMenu,5,!x.tickname
        END
    7: BEGIN
          ModifTickDef, 'Y'
          TicksChange,mainMenu,6,!y.tickname
        END
    8: BEGIN
          ModifInterval, 'X'
          Intervals, mainMenu, 7, !x.ticks
         END
    9: BEGIN
          ModifInterval, 'Y'
          Intervals, mainMenu, 8, !y.ticks
         END
    10: BEGIN
          ModifMarksNr, 'X'
          MinorTicksNr, mainMenu, 9, !x.minor
        END
    11: BEGIN
            ModifMarksNr, 'Y'
            MinorTicksNr, mainMenu, 10, !y.minor
          END
    12: BEGIN
            ModifStyle, 'X'
            AxisStyle, mainMenu, 11, !x.style
           END
    13: BEGIN
            ModifStyle, 'Y'
            AxisStyle, mainMenu, 12, !y.style
           END
    14: BEGIN
            IF !x.type EQ 1 THEN !x.type = 0 ELSE !x.type = 1
            AxisType, mainMenu, 13, !x.type
           END
    15: BEGIN
            IF !y.type EQ 1 THEN !y.type = 0 ELSE !y.type = 1
            AxisType, mainMenu, 14, !y.type
           END
    16: BEGIN
              IF !p.font EQ 0 THEN BEGIN
                Read_Test,'Please enter the character size ',1,charsize
                mainMenu(15) = 'Software Font, size '+StrTrim(charsize,2)
                charSize = 0 > charsize < 10.0 
                !p.charsize = charsize
                !p.font = -1
              ENDIF ELSE BEGIN
                mainMenu(15) = 'Hardware Font'
                !p.font = 0
              ENDELSE
           END
     17: BEGIN
             IF hms EQ 0 THEN BEGIN
               hms = 1 
               mainMenu(16) = 'X axis in Hours/Min/Sec.'
             ENDIF ELSE BEGIN
               hms = 0
               mainMenu(16) = 'X axis in Decimal Notation'
             ENDELSE
             PutHMS, hms
           END
      18: BEGIN
              names = GetNames()
              offsetZero = FltArr( N_Elements( names ) )
              InsertPlot, names, ud,  ud, ud, ud, ud, ud, $
	ud, ud, ud, offsetZero
            END
      ELSE:
  ENDCASE
END UNTIL choice EQ mainMenuLength-1

  PutTitles, !p.title, !x.title, !y.title, !p.subtitle

END       
          
