; MODULE Init Display

;+
; NAME:
;	Init_Display
; PURPOSE
;   	Every constant for displaying  images on screen is
;   	defined in this procedure. Unless specified, the constants
;   	are defined in device pixels.
;   	Procedure to access the constants  ( Put and Get ) are 
;	compiled the first time the procedure "Init Display" is run
; CALLING SEQUENCE:
;	Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;	noMinMax variable in Nov 93, A.Cs
;-


PRO GetWinSize, xSizeP, ySizeP, PS = ps

;+
; NAME:
;	Get Window Size
; PURPOSE:
;	Reads the variables defining the window size
; CALLING SEQUENCE:
;	GetWinSize, xSize, ySize
; OUTPUTS:
;	xSize, ySize: the size of the window or page
; KEYWORD:
;	PS: if set, the size of the page is in the variables
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-

  COMMON Sizes, size, d1, d2, d3, d4

  IF NOT Keyword_Set( PS ) THEN ps = 0

  xSizeP = size.x.(ps)
  ySizeP = size.y.(ps)

END ; Get Window Sizes


PRO GetImageSizes, xPosP, yPosP, widthP, heightP, scaleheightP, $
	PS = ps
;+
; NAME:
;	Get Image Sizes
; PURPOSE:
;	Reads the variables defining the image size
; CALLING SEQUENCE:
;	GetImageSizes, xPos, yPos, width, height scaleheight
; OUTPUTS:
;	xPos, yPos: the position of the origin  of the image
;	width, height: the size of the image
;	scaleheight: the height of the scale showing the contrasts
;		of the color table.
; KEYWORD:
;	PS: if set, the values for printing on a  page are in the
;		 variables (in cm)
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-

  COMMON Sizes, d1, pos, scale, width, height

  IF NOT Keyword_Set( PS ) THEN ps = 0

  xPosP = pos.x.(ps)
  yPosP = pos.y.(ps)
  widthP = width.(ps)
  heightP = height.(ps)
  scaleheightP = scale.(ps)

END ; Get Image Sizes


PRO PutWinSize, xSizeP, ySizeP, PS = ps

;+
; NAME:
;	Put Window Size
; PURPOSE:
; 	Writes the variables defining the window size
; CALLING SEQUENCE:
;	PutWinSize, xSize, ySize
; OUTPUTS:
;	xSize, ySize: the size of the window or page
; KEYWORD:
;	PS: if set, the size of the pageare stored
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-

   COMMON Sizes, size, d1, d2, d3, d4

  IF NOT Keyword_Set( PS ) THEN ps = 0

  IF N_Elements(xSizeP) NE 0 THEN size.x.(ps) = xSizeP
  IF N_Elements(ySizeP) NE 0 THEN size.y.(ps) = ySizeP

END ; Put Window Sizes


PRO PutImageSize, xPosP, yPosP, widthP, heightP, scaleheightP, $
	PS = ps

;+
; NAME:
;	Put Image Sizes
; PURPOSE:
;	Writes the variables defining the image size
; CALLING SEQUENCE:
;	PutImageSizes, xPos, yPos, width, height scaleheight 
; INPUTS:
;	xPos, yPos: the position of the origin  of the image
;	width, height: the size of the image
;	scaleheight: the height of the scale showing the contrasts
;		of the color table.
; KEYWORD:
;	PS: if set, the values for printing on a  page are stored
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-
  COMMON Sizes, d1, pos, scale, width, height

  IF NOT Keyword_Set( PS ) THEN ps = 0
    
  IF N_Elements(xPosP) NE 0 THEN pos.x.(ps) = xPosP
  IF N_Elements(yPosP) NE 0 THEN pos.y.(ps) = yPosP
  IF N_Elements(scaleheightP) NE 0 THEN $
	scale.(ps) = scaleheightP
  IF N_Elements(widthP) NE 0 THEN width.(ps) =  widthP 
  IF N_Elements(heightP) NE 0 THEN height.(ps) = heightP 

END


PRO PutOffsets, axisOffsetP, imageOffsetP, PS = ps

;+
; NAME:
;	Put Offsets
; PURPOSE:
;	Writes the offsets of axes and image parts
; CALLING SEQUENCE:
;	PutOffsets, axisOffset, imageOffset
; INPUTS:
;	axisOffset: the offset between axis and image
;	imageOffset: the offset between image parts (for
;		non-regular axes.
; KEYWORD:
;	PS: if set, the values for printing on a  page are stored
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-

  COMMON Axes, axisOffset, imageOffset

  IF NOT Keyword_Set( PS ) THEN ps = 0
    
  IF N_Elements(axisOffsetP) NE 0 THEN axisOffset.(ps) = axisOffsetP
  IF N_Elements(imageOffsetP) NE 0 THEN $
	imageOffset.(ps) = imageOffsetP

END ; Put Offsets


PRO GetOffsets, axisOffsetP, imageOffsetP, PS = ps

;+
; NAME:
;	Get Offsets
; PURPOSE:
;	Reads the offsets of axes and image parts
; CALLING SEQUENCE:
;	GetOffsets, axisOffset, imageOffset
; OUTPUTS:
;	axisOffset: the offset between axis and image
;	imageOffset: the offset between image parts (for
;		non-regular axes.
; KEYWORD:
;	PS: if set, the values for printing on a  page are stored
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-
  COMMON Axes, axisOffset, imageOffset

  IF NOT Keyword_Set( PS ) THEN ps = 0
    
  axisOffsetP = axisOffset.(ps)
  imageOffsetP = imageOffset.(ps)

END ; Get Offsets


PRO GetMiscPS, encaps, landsc, rev, blFontP, reducedFmtP, noMinMaxP

;+
; NAME:
;	Get Miscellaneous
; PURPOSE:
;	Reads som information needed for printing
; CALLING SEQUENCE:
;	GetMiscPS, encapsulated, landscape, reverse, blackFont
; OUTPUTS:
;	encapsulated: if not zero, the image will be encapsulated
;		with the command "\insertimage" or
;		"\insertplot" in a TeX file.
;	landscape: if not zero, the page is printed landscape
;	reverse: if not zero low values are printed white, 
;		high values black.
;	blackFont: if not zero, the background color of the page
;		is black.
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-
  COMMON PSMisc,  encapsulated, landscape, reverse, blFont, $
	reducedFmt, noMinMax

  encaps = encapsulated
  landsc = landscape
  rev = reverse
  blFontP = blFont
  reducedFmtP = reducedFmt
  noMinMaxP = noMinMax

END ; Get Miscellaneous
    

PRO PutMiscPS, encaps, landsc, rev, blFontP, reducedFmtP, noMinMaxP

;+
; NAME:
;	Put Miscellaneous
; PURPOSE:
;	Writes some information needed for printing
; CALLING SEQUENCE:
;	PutMiscPS, encapsulated, landscape, reverse, blackFont
; INPUTS:
;	encapsulated: if not zero, the image will be encapsulated
;		with the command "\insertimage" or
;		"\insertplot" in a TeX file.
;	landscape: if not zero, the page is printed landscape
;	reverse: if not zero low values are printed white, 
;		high values black.
;	blackFont: if not zero, the background color of the page
;		is black.
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;	reducedFmt added in Jun 93, A.Cs
;-
  COMMON PSMisc, encapsulated, landscape, reverse, blFont, $
	reducedFmt, noMinMax

  encapsulated  = encaps
  landscape = landsc 
  reverse = rev  
  blFont = blFontP  
  reducedFmt = reducedFmtP
  noMinMax = noMinMaxP

END ; Put Miscellaneous


PRO GetBreaks, dxBreaksP, dyBreaksP

;+
; NAME:
;	Get Breaks
; PURPOSE:
;	Reads the indices where  breaks occur in the axex.
; CALLING SEQUENCE:
;	GetBreaks, dxBreaks, dyBreaks
; OUTPUTS:
;	dxBreaks, dyBreaks: arrays containig the indices where a
;		break occur in the x- respectively y-axis.
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-
  COMMON BothDisplays, hms, dxBreaks, dyBreaks, marksMode

  dxBreaksP = dxBreaks
  dyBreaksP = dyBreaks

END ; Get Breaks


PRO PutBreaks, dxBreaksP, dyBreaksP

;+
; NAME:
;	Put Breaks
; PURPOSE:
;	Writes the indices where  breaks occur in the axes.
; CALLING SEQUENCE:
;	PutBreaks, dxBreaks, dyBreaks
; OUTPUTS:
;	dxBreaks, dyBreaks: arrays containig the indices where a
;		break occur in the x- respectively y-axis.
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, April 91
;-

  COMMON BothDisplays,  hms, dxBreaks, dyBreaks, marksMode

  dxBreaks = dxBreaksP
  dyBreaks = dyBreaksP

END ; Put Breaks


PRO GetMarksMode, xMarkMode, yMarkMode

;+
; NAME:
;	Get Marks Mode
; PURPOSE:
;	Reads the mode in which the axes are to be drawn:
;		'automatic': the change between range and single pixel
;			marking is done by the program
;		'range': the program does alwas a range marking.
; CALLING SEQUENCE:
;	GetMarksMode, xMarkMode, yMarkMode
; OUTPUTS:
;	xMarksMode, yMarksMode: 'automatic' or 'range'
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, October 93
;-
  COMMON BothDisplays, hms, dxBreaks, dyBreaks, marksMode

  xMarkMode = marksMode.x
  yMarkMode = marksMode.y

END ; Get Marks Mode


PRO PutMarksMode, xMarkMode, yMarkMode

;+
; NAME:
;	Put Marks Mode
; PURPOSE:
;	Stores the axis drawing mode:
;		'automatic': the change between range and single pixel
;			marking is done by the program
;		'range': the program does alwas a range marking.
; CALLING SEQUENCE:
;	PutMarksMode, xMarkMode, yMarkMode
;INPUTS:
;	xMarkMode, yMarkMode: 'automatic' or 'range'
; RESTRICTION:
;	Works only after initialization by calling Init_Display
; HISTORY
;	Created: A.Csillaghy, ETHZ, October 93
;-

  COMMON BothDisplays,  hms, dxBreaks, dyBreaks, marksMode

  marksMode.x = xMarkMode
  marksMode.y = yMarkMode

END ; Put Marks Mode


PRO Init_Display

  COMMON Sizes, size, $ ; the size of the window in dev.pix.
	pos,  $ ; the position of the lower left corner
	scale,  $
	width, height  ; the dimension of the image in the window
  COMMON Axes, axisOffset, $ ; the nb of pix betw im and axis
	imageOffset
  COMMON PSMisc, encapsulated, landscape, reverse, blFont, $
	 reducedFmt, noMinMax
  COMMON BothDisplays, hms, dxBreaks, dyBreaks, marksMode


  dev = { psOrScr,  scr: 0,  ps: 0.0 }
  coord = { xy, x: dev, y: dev }

  size = { xy } 
  pos = { xy }
  scale = {psOrScr }
  width = { psOrScr }
  height = { psOrScr }
  axisOffset = { psOrScr }
  imageOffset = {psOrScr }

  size.x.ps = 20. & size.y.ps = 20.
  size.x.scr = 600 & size.y.scr = 600
  
  pos.x.scr = 45 & pos.y.scr = 37
  pos.x.ps = 1. & pos.y.ps = 2.

  scale.scr  = 15 & scale.ps = 0.5

  FOR i = 0,1 DO BEGIN
    width.(i) = size.x.(i) - 2*pos.x.(i) 
    height.(i) = size.y.(i) - 3*pos.y.(i) - scale.(i)
  ENDFOR
  
  axisOffset.scr = 15 & axisOffset.ps = 0.5
  imageOffset.scr = 5 & imageOffset.ps = 0.1

  hms = 1

  encapsulated = 0
  landscape = 1
  reverse = 0
  blFont = 0
  reducedFmt = 0
  noMinMax = 0
  marksMode = {MarksType, x: 'automatic', y: 'automatic'}

END