PRO Change_Selection, z, xAxis, yAxis, $
	xMin, xMax, yMin, yMax, STATUS = status, $
	FNAME = fName, TEXT = text

;+
; NAME: 
;	Change_Selection
; PURPOSE:
;	Restores an image interactively choseN from the list of
;	files with ending ".tmpenrad".
; CALLING SEQUENCE:
;	Change_Selection, image, xAxis, yAxis, 
;	 	[ xMin, xMax, yMin, yMax]
; OUTPUTS:
;	image: the 2D array
;	xAxis, yAxis: the 1d arrays corresponding to the image
;	xMin, xMax, yMin, yMax: the boundary of the image (in
;		pixel number) when it was stored.
; KEYWORDS:
;	STATUS: "Done" or "Not Done" as result
;	FNAME: The filename. If set, the interactive part is 
;		not used.
;	TEXT: If not set, the menu of the interactive part contains 
;		the text: "Select image"
; RESTRICTION:
;	Works only after initialization with "Init_selection".
; LOCATION: 
;	init_selection.pro
;-

  COMMON Selection2D, images, d1, d2, d3, dir

  IF NOT Keyword_Set( TEXT ) THEN text = 'Select Image'
  nbIms = N_Elements(images)

  IF nbIms EQ 0 THEN BEGIN
    Print,'No or only one image in memory ... '
    Print, ''
    status = "Not Done"
    RETURN
  ENDIF

  choice = General_Menu( $
	 [images, 'Exit this Menu'], $
	 text )
  IF choice EQ nbIms+1 THEN BEGIN
    status = "Not Done"
    RETURN
  ENDIF
  imSel = images(choice-1)
  fName = StrMid(imSel, 0, StrLen(imSel)-10)
  Restore, FILENAME = dir + '/' + fName + '.tmpenrad'
 
  status = "Done"

END; change selection


PRO Put_Selection, z, xAxis, yAxis, xMin, xMax, yMin, yMax, $
	FILESTATE = fileState, FNAME = fName

;+
; NAME:
;	put selection
; PURPOSE:
;  	Save the image "fname" in a file with ending
;	".tmpenrad". 
;	Delete an temporary image if necessary.
; CALLING SEQUENCE:
;	Put_Selection, z, xAxis, yAxis, xMin, xMax, yMin, yMax
;  INPUT ARGUMENTS:
;	image: the 2D array
;	xAxis, yAxis: the 1d arrays corresponding to the image
;	xMin, xMax, yMin, yMax: the boundary of the image (in
;		pixel number) when it was stored.
; KEYWORDS:
;	FILESTATE: either "temporary" or "permanent"
;		(default: "temporary")
;	FNAME: ther file name. default: compression of !p.title
; SIDE EFFECT:
; 	a file is written or/and replaced, in the directory specified
;	by ENRAD_SAVE env. variable
; MODIFICATION:
;	Created in may 1991 by A.Csillaghy, ETHZ.
;	Modified for ENRAD_SAVE in Jan. 93, A.Cs.
;-

  COMMON Selection2D, images, wNr, tmpWins, wMax, dir
  COMMON Versions, v

  IF N_Elements( v ) EQ 0 THEN v = 0
 
  IF NOT Keyword_Set(FILESTATE) THEN fileState = "temporary"
  IF NOT Keyword_Set(FNAME) THEN $
    fName = StrCompress( repchr(repchr(repchr(repchr(repchr(!p.title, $
                         '/'),':'),'('),'('), '+'), /REMOVE_ALL)
  
  fNameState = fName + ' ' +  filestate

  IF images(0) EQ '' THEN BEGIN images = fNameState  
  ENDIF ELSE BEGIN 
    idx = Where( images EQ fNameState )
    IF Total( idx ) NE -1 THEN BEGIN
      IF Total(StrPos(images(idx),'temporary',0)) NE -1 THEN BEGIN
        fName = fName + '_v' + StrTrim( v , 2 )
        v = v+ 1
        fNameState = fName + ' ' + fileState
      ENDIF
    ENDIF
    images = [ images, fNameState ]
  ENDELSE

  nbEls = N_Elements( images )
  IF filestate EQ "temporary" THEN BEGIN
    tempArr = Where(StrPos( images, "temporary" ) NE -1)
    IF N_Elements( tempArr ) GT tmpWins THEN BEGIN
      fToRm = StrMid( images(tempArr(0)), 0, $
	StrLen(images(tempArr(0)))-10) + '.tmpenrad'
      fToRm = dir + '/' + fToRm
      Spawn, 'rm -f  ' + fToRm
      imIdx = tempArr(0)
      CASE 1 OF
        (imIdx EQ 0) : images = images(1:nbEls-1)
        ( 0 LT imIdx) AND (imIdx LT nbEls): $
          images = [images( 0:imIdx-1),images(imIdx+1:nbEls-1)]
        (imIdx EQ nbEls-1): images = images(0:nbEls-1)
      ENDCASE
    ENDIF
  ENDIF
  
  Save,  z, xAxis, yAxis, xMin, xMax, yMin, yMax, $
	FILENAME = dir + '/' + fName+'.tmpenrad',  $
	/SYSTEM_VARIABLES

END


PRO Sel_Del, ALL = all, DIRECTORY = directory

;+
; NAME:
;	Selection delete
; PURPOSE:
;	Deletes one or more save files. Optionally deletes the 
;	save directory in ENRAD_SAVE also.
; CALLING SEQUENCE:
;	Sel_Del
; KEYWORDS:
;	ALL: If specified, all save files are deleted.
;	DIR: If specified, the whole save directory is deleted
; SIDE EFFECT:
;	If no keywors is specified, the file to delete is asked
;	interactively with a menu.
; MODIFICATION HISTORY:
;	Created in Oct. 91 by A.Csillaghy, ETHZ
;	Modified in Jan 93 for ENRAD_SAVE, A.Cs
;-

  COMMON Selection2D, images, d1, d2, d3, dir
    
  nbEls = N_Elements(images)

  IF NOT Keyword_Set(ALL) THEN BEGIN
    choice = General_Menu([images,'Return to Main Menu'], $
	'Choose the Image to Remove')

    IF choice EQ nbEls+1 THEN RETURN
    
    imSel = images(choice-1)
    name = StrMid(imSel,0,StrLen(imSel)-10)

    IF (choice NE 1) AND (choice NE nbEls) THEN $
     images = images(0:choice-2,choice:nbEls-1) $
    ELSE IF choice EQ 1 THEN images = images( 1: nbEls-1) $
    ELSE images = images(0:nbEls-2 )

    Spawn,' rm -f  '+dir + '/'+ name+'.tmpenrad'

  ENDIF ELSE BEGIN
    Spawn,'rm  -f  ' + dir + '/'+ '*.tmpenrad' 
    IF Keyword_Set( DIRECTORY ) THEN BEGIN 
      Spawn, 'ls -a '+ dir , response
      IF N_Elements( response ) LE 3 THEN Spawn, 'rm -f -r ' + dir
    ENDIF 
  ENDELSE

END ; Sel Del

  
PRO Window_Management, z, x, y, xMin, xMax, yMin, yMax, $
	STATUS = status, FNAME = fName

  COMMON Selection2D, images, d, nbTemps,  wMax, dummy

  IF !d.name NE 'X' THEN RETURN

  mainMenuLength = 8
  	
  mainMenu = StrArr(mainMenuLength)

  mainMenu(0) = 'Number of Windows: '+ StrTrim( wMax, 2 )
  mainMenu(1) = 'Number of Temporary States Kept: '+ $
	StrTrim(nbTemps,2)
  mainMenu(2) = 'Select an Image ... '
  mainMenu(3) = 'Remove an Image from the Selection List ... '
  mainMenu(4) = 'Erase the Windows '
  mainMenu(5) = 'Display the selected Image'
  mainMenu(6) = 'Exit Window and Selection Management Menu'
  mainMenu(7) = 'Redisplay this Menu'

  status = "Not Done"

  REPEAT BEGIN
    

    choice = General_Menu( mainMenu, $
	'Window and Selection Management: choose Option')

    CASE choice OF
      1: REPEAT BEGIN
             Read_Test,'Plese enter the new number of windows '+ $
	'to use for enrad', wMax, wMaxP
             wMax = Fix(wMaxP)
             mainMenu(0) = 'Number of Windows: '+ StrTrim( wMax, 2 )
          END UNTIL wMax LT 15 AND wMax GT 0
      2: REPEAT BEGIN
             Read_Test,'Please enter the new number of temporary states ', $
	 nbTemps, nbTempsP
             nbTemps = Fix( nbTempsP )
             mainMenu(1) = 'Number of Temporary States Kept: '+ $
	StrTrim(nbTemps,2)
          END UNTIL nbTemps LT 10 AND nbTemps GT 0
      3: Change_Selection, z, x, y, xMin, xMax, yMin, yMax, $
	STATUS = status, FNAME = fName
      4: Sel_Del
      5: BEGIN 
            WHILE !d.window NE -1 DO WDelete
            status = "Done"
          END
      6: BEGIN 
             Image_Info, z(xMin:xMax, yMin:yMax), x(xMin:xMax), $
	y( yMin: yMax )
             Show_Image, z( xMin: xMax, yMin: yMax), $
	x( xMin: xMax), y( yMin: yMax), /SIZES_ON, $
	WINNR = GetWNr(), WNAME = fName
          END
    ELSE:
    ENDCASE

  END UNTIL choice EQ mainMenuLength-1

END ; Window_Management


PRO Init_Selection

;+
; NAME:
;	Initialize Selection
; PURPOSE:
;	Compiles the routines for the ragview image selection an 
;       window management system.
;	Initializes the system  with default values.
; CALLING SEQUENCE:
;	Init_Selection
; SIDE EFFECT:
;	A directory for save files is created.
;       This directory can be specified with $RAGVIEW_DIR. 
;       Default is: $HOME/.ragview
;	device is defined in environment
;	varable ENRAD_SAVE. If this varaible is not defined,
;	the save files ar written in the current directory.; SIDE EFFECT:
;	If the user has no directory on the scratch device, one will
;	be created.
; MODIFICATION HISTORY:
;	Created in Oct 91 by A.Csillaghy, ETHZ, csillag@astro.phys.ethz.ch
;	Modified for ENRAD_SAVE in Jan 93, A.Cs.
;	Modified for Ragview / IDL 5 in March 98, ACs
;-

  COMMON Selection2D, images, wNr, nbTemps, nbWMax, dir

  nbWMax = 1
  images = ''
  wNr = -1
  nbTemps = 4
  dir = GetEnv( 'RAGVIEW_SAVE' )
  IF dir EQ '' THEN BEGIN
    dir = GetEnv( 'HOME' )
  ENDIF
  dir = dir + '/.ragview'
  dummy = FindFile( dir, COUNT = nb )
  IF nb EQ 0 THEN $ 
      Spawn, ' mkdir ' + dir, response
  

END ; Init Selection


