;+
; NAME:
;	Plots_Selection
; PURPOSE:
;	User interface, programmed for the mdisp system
;	but usable also alone, to select and remove plots that
;	have been stored in the plot table (see store_plot)
;	from the selection, in order to be displayed by 
;	Data_Display.
; CATEGORY:
;	User Interface
; CALLING SEQUENCE:
;	Plots_Selection
; SIDE EFFECT:
; 	Windows are opened.
; RESTRICTION:
;	Use only in interactive mode
; MODIFICATION HISTORY:
;	Created in June 1991 by A.Csillaghy
;		Inst. of Astronomy, ETH Zurich
;-

PRO ShowSelection, selectedMenu, $
	DELETE = delete, NODISPLAY=noDisplay

  COMMON ShowSel, winNr

  IF N_Elements(winNr) NE 0 THEN $
    IF winNr NE 999 THEN BEGIN
      WDelete, winNr & winNr = 999
    ENDIF

  IF Keyword_Set(DELETE)  THEN RETURN

  nbSel = N_Selected()
  IF nbSel GT 0 THEN BEGIN
    nbLines = 20*( !d.name NE 'X') + 40*( !d.name EQ 'X' )
    j = nbLines
    plotsSelected = GetNames( /SELECTION )
    selectedMenu = plotsSelected( 0: nbSel < nbLines - 1  )
    WHILE j LT nbSel DO BEGIN
       idxMax = (nbSel - j) < nbLines - 1
       selectedMenu( 0: idxMax ) = selectedMenu(  0: idxMax ) + $
	' | ' + plotsSelected( j:j+idxMax)
       j = j + 40
    ENDWHILE

    IF N_Elements(selectedMenu) GT 1 THEN $
      selectedMenu = Rotate( selectedMenu, 2)
    IF NOT Keyword_Set(NODISPLAY) THEN $
      IF !d.name EQ 'X' THEN $
        winNr = WMesg( selectedMenu, 'Plots Selected', 500,500) $
      ELSE Print, selectedMenu, nbSel
  ENDIF ELSE IF NOT Keyword_Set(NODISPLAY) THEN $
    IF !d.name EQ 'X' THEN $
      winNr = WMesg( 'No Plots Selected', 'Plots Selected', 200,500) $
    ELSE Print, 'No Plots Selected'

END


PRO Plots_Selection

IF No_Data() THEN BEGIN
  Print,' You should first get data from file ... '
  Print, ''
  RETURN
ENDIF

ShowSelection

mainMenuLength = 6
mainMenu = StrArr(mainMenuLength)
mainMenu(0) = 'Add a Plot to the Selection'
mainMenu(1) = 'Remove a Plot from the Selection'
mainMenu(2) = 'Clear the Selection'
mainMenu(3) = 'Select All'
mainMenu(4) = 'Return to Main Menu'
mainMenu(5) = 'Redisplay this Menu'

REPEAT BEGIN
  choice = General_Menu(mainMenu, $
	' Selection of Plots: Choose Option', /NO_CLEAR)
  names = GetNames()
  ShowSelection,/DELETE
  CASE choice OF
    1: REPEAT BEGIN
          choiceAdd = General_Menu( [names, 'EXIT' ], $
	'Choose the Plot to Add to the Selection or Exit')
          exitCond = choiceAdd EQ N_Elements(names)+1
          IF NOT exitCond THEN InsertSel, names(FIX(choiceAdd)-1)
        END UNTIL exitCond
    2: REPEAT BEGIN
          names = GetNames( /SELECTION )
          choiceRem = General_Menu( [names, 'EXIT'] , $
	'Choose the Plot to Remove from the Selection or Exit')
          exitCond = choiceRem EQ N_Elements(names)+1
          IF NOT exitCond THEN RemoveSel, names(choiceRem-1)
        END UNTIL exitCond
    3: InitSel
    4: SelectAll
  ELSE:
  ENDCASE
  IF choice LT mainMenuLength-1 THEN ShowSelection $
  ELSE ShowSelection, /DELETE
END UNTIL choice EQ mainMenuLength-1

; !x.range = [0,0] & !y.range = [0,0]

END

