PRO Ragview_MDisp_Int, image, xAxis, yAxis, $
   	xTitle, YDIR = yDir, $
	RESET = reset, TITLE = title

;+
; NAME: 
;	Ragview_MDisp_Int
; PURPOSE:
; 	Interface used to transfer data from the two dimensional
;       image analysis software RagView to its one-dimensional 
;       subsystem mdisp. The vectors of the transfered image will be \
;       stored in a plot table.
; CATEGORY:
;	Data Management
; CALLING SEQUENCE:
;	RagView_MDisp_Int, image [, xAxis, yAxis ]
; INPUTS
;	image: the array to transfer.
;	xAxis, yAxis: the x and y axes of the image
; KEYWORDS:
;	/YDIR: if present, the image is decomposed in y-plots
;              if not present x-plots are created.
;	/RESET: if present, the former plot table will be erased.
;	TITLE: The name of the plot. Deafult: "!p.title".
; MODIFICATION HISTORY:
; 	Created in June 1991 by A.Csillaghy 
;       Few modifications for Ragview/ssw/IDL5 in March 1998, ACs.
;-

  IF NOT Keyword_Set(TITLE) THEN  title = !p.title

  IF N_Elements( xTitle ) EQ 0 THEN xTitle = ''

  nx = N_Elements( image(*, 0))
  ny = N_Elements( image(0,* ))

  CASE N_Params() OF
    0: BEGIN
          Error, 7, 'RagWiew-Mdisp Interface'
          RETURN
        END
    1: BEGIN yAxis = LIndGen( ny ) & xAxis = LIndGen( nx ) & END
    2: yAxis = LIndGen(ny )
    3:
    ELSE: 
  ENDCASE

  Init_Data
  hms = GetHMS()
  PutTitles, title,  xTitle, !z.title, ''

  name = StrMid(StrCompress(!p.title,/REMOVE_ALL),0,10)

  maximum = Max( image )

  nbEls = N_Elements(yAxis) < 300
  FOR i=0,nbEls-1 DO BEGIN
    IF Keyword_Set( YDIR ) AND hms EQ 1 THEN $
      item = HMSConvert(yAxis(i)) $
    ELSE item = StrTrim(yAxis(i),2)
    nameToStore = name+ ' ' + item
    InsertPlot, nameToStore, N_Elements(xAxis), $
	xAxis, image(*,i), undef, undef, undef, undef, undef, $
   	undef,  (0.5*maximum)*i, undef, undef, $
	title,  xTitle, !z.title, /NEW
  ENDFOR

  IF nbEls EQ 1 THEN InsertSel, nameToStore

END
