PRO Adjust_Table,vectorTable, newLength

; Procedure to change the length of the plot table stored
; in the COMMON Data.
;
; Created by A.Csillaghy in June 1991

tableLength = N_Elements(vectorTable(0,*))
newTable = Replicate( 0.0, newLength, tableLength )
newTable(0,0) = vectorTable
vectorTable = newTable

END ; Adjust  Table


PRO Insert, vector, vectorTable, tableSize, index

; Inserts a vector in the vector table.

  nbEls = N_Elements(vector)
  tableLen = N_Elements(vectorTable(*,0))
    IF nbEls GT tableLen THEN BEGIN
       Adjust_Table, vectorTable, nbEls
       tableLen = nbEls
    ENDIF ELSE IF nbEls LT tableLen THEN BEGIN
       newVector = Replicate( 0.0, tableLen )
       newVector(0) = vector 
       vector = newVector
    ENDIF
    index = 0 &  done = 0
    WHILE (index  LT tableSize) AND (NOT done) DO BEGIN
      IF TOTAL(vector EQ vectorTable(*,index) ) NE nbEls  THEN $
         index = index+1 $
      ELSE done = 1
    ENDWHILE
    IF index EQ tableSize THEN BEGIN
       vectorTable = [ [vectorTable], [vector] ]
       tableSize = tableSize+1
    ENDIF

END ; Insert


PRO InsertArr, vectArr, vectorTable, tableSize, listEl, listTagNr

  listTagNr = listTagNr(0)
  IF N_Elements(vectArr) GT 0 THEN BEGIN
    nbVect = N_Elements(vectArr(0,*))
    IF nbVect NE 0 THEN BEGIN
      FOR i = 0,nbVect-1 DO BEGIN
        Insert, vectArr(*,i), vectorTable, tableSize,index
        listEl(i).(listTagNr) = index
      ENDFOR
    ENDIF
  ENDIF ELSE listEl.(listTagNr) = 0

END ; InsertArr

    
PRO Store_Plot,fName,x,y,qualifier,dxl,dyu,dxr,dyd, $
	LENGTHVEC = lengthVec

;+
; NAME: 
;	Store_Plot
; PURPOSE:
;	Stores plot named "name" in the plot table. If
; 	a name  is already in the table, the corresponding
;	plot is renamed
;	"name_vx" where "x" is a number to identify the plot.
; CATEGORY:
;	Data Management
; CALLING SEQUENCE:
;	Store_Plot, name [, x,  y [, qualifier [, dxLeft, dyUp
;		[, dxRight, dyDown ] ] ]
; INPUTS:
;	name: the names of the plots, a string array
;	x, y : the points to be plotted, an array of vectors;
;	qualifier: the symbol number with which the points should
;		be plotted, (arrays of vectors);
;	dxLeft, dxRight, dyUp, dyDown: the error of the points
;		in x or y direction, (arrays of vectors);
;	If more than one plot should be stored in the table, 
;	the x-axis of the 2D array is the vector direction.
; COMMON BLOCKS
;	Versions, to track the number of versions of the same plot.
;	Data, where the plot table is stored.
;	Both blocks are opaque.
; SIDE EFFECT:
;	An entry is created in the plot table.
;-
; MODIFICATION HISTORY:
;	Created in July 1991 by A.Csillaghy,
;		Instituite of Astronomy, ETH Zurich
;	Redesigned in August 1991 for higher efficiency, A.Cs.


COMMON Versions, v
COMMON Data, plotList,vectorTable

nbEls = N_Elements(fName)
IF  nbEls EQ 0 THEN BEGIN
  Print,' The name of the plot should be given ... '
  Print,' WARNING: the plot is not stored in the plot table '
  RETURN
ENDIF

IF TOTAL(Search_Plot(fName)) NE -1 THEN BEGIN
    IF N_Elements(v) EQ 0 THEN v=1
    index = Where( Search_Plot(fName) NE -1 )
    fName( index )= fName(index)+'_v'+StrTrim(v,2)
    v = v+1
ENDIF

p = Replicate( {plotType}, nbEls )
FOR i = 0,nbEls-1 DO p(i).name = fName(i)
IF Keyword_Set(LENGTHVEC) THEN p.len = lengthVec $
ELSE p.len = N_Elements(y(*,0))

tableSize = N_Elements(vectorTable(0,*))

tagNames = Tag_Names(p)
first = Where( tagNames EQ 'X' )

InsertArr, x, vectorTable, tableSize, p, first
InsertArr, y, vectorTable, tableSize, p, first+1
InsertArr, qualifier, vectorTable, tableSize, p, first+2
InsertArr, dxl, vectorTable, tableSize, p, first+3
InsertArr, dyu, vectorTable, tableSize, p, first+4
InsertArr, dxr, vectorTable, tableSize, p, first+5
InsertArr, dyd, vectorTable, tableSize, p, first+6

plotList = [ plotlist, p ]

END