PRO AxisTime, yPos, axisRange, ps, AXISTYPE = axisType, $
	NOLABELS = noLabels, NORMAL = normal, $
	CHARSIZE = charSize

;+
; NAME:
;	Axis Time
; PURPOSE:
;	Writes x axis with hours / minutes / seconds labels
; CALLING SEQUENCE:
;	AxisTime, yPosition, range [, ps]
; INPUT PARAMETERS:
;	yPosition: the height where the horizontal axis is placed
;	axisRange = a 2-element array containing the minimum 
;		and maximum of the plot
;	ps: is 1 if the device is PostScript, 0 otherwise.
; KEYWORDS: 
;	AXISTYPE = 1 -> axis has ticks down
;	AXISTYPE = 0 -> axis has ticks up
;	/NOLABELS: The tick names are not drawn
;	/NORMAL: The values given in the parameters are
;		in normalized coordinates. Default: device
;		coordinates.
;	CHARSIZE: defines the (relative) character size.
;		Default: !p.charsize
; SIDE EFFECT:
;	In the current plot window, an axis with time units is 	;	drawn.
; RESTRICTION:
;	The axis range is continuous.
; SEE ALSO
;	enrad, show_image
; MODIFICATION HISTORY:
;	Written in November 1991 by A.Csillaghy
;		Inst. of Astronomy, ETH Zurich.
;	Heavy modifications in July 1992 for better display. A.Cs
;	Thresholds for drawing the labels lower modified, A.Cs
;		Dec. 92
;	Adaptation of tick marks in ps format: Jun 93, A.Cs
;	CHARSIZE in Nov 94, ACs.
;-

  IF NOT Keyword_Set( AXISTYPE ) THEN axisType = 0
  IF NOT Keyword_Set( CHARSIZE ) THEN charSize = !p.charSize
  IF NOT Keyword_Set( NOLABELS ) THEN noLabels = 0 $
  ELSE noLabels = 1
  IF N_Elements( ps ) EQ 0 THEN ps = 0

  dispLim = 300*ps + 10*(ps EQ 0)

  vals = [ 1, 5, 10, 60, 3600, 7200 ]

  sign = (-1)^(axisType)
  rangeRel = !x.window(1)-!x.window(0)
  rangeDev = rangeRel*!d.x_size
  nTicksMax = Fix(rangeDev/dispLim) > 1

  exactRange = Abs( axisRange(1) - axisRange(0) ) 

;1. test if any range present
  dilatation = 1
  REPEAT BEGIN
    ranges = Long(exactRange) / vals
    tot = Total( ranges )
    IF tot EQ 0 THEN BEGIN
      exactRange = exactRange*10
      dilatation = dilatation * 10
    ENDIF
  END UNTIL tot NE 0
; here, a range is present.  Now find out which ticks to write


  i = 0
  WHILE ranges(i+1) GT 1 AND i LT 4 DO  i = i+1


; the nb of main ticks is in selection(i) and the nb of secondary ticks
; is in selection(i-1)
 
  indexLow = (i-1)>0
; stopped on 13.6.94  nTicks = (ranges(indexLow:i) < nTicksMax) +1
  nTicks = ranges(indexLow:i) +1

  IF !d.name NE 'PS' THEN psfact = 1 ELSE psFact=100
  WHILE (nTicks(0)*psfact GT 0.25*rangeDev) $
	AND Total( vals ) NE 0 DO BEGIN
    nTicks = nTicks / 2
    vals = vals*2
  ENDWHILE

  fixAxisR0 = Long( axisRange(0) )
  err =  axisRange(0) - fixAxisR0 
  offsets =(fixAxisR0-(fixAxisR0 MOD vals(indexLow:i)) + $
	vals(indexLow:i) ) - axisRange(0)

;create the labels

  factor = rangeRel/exactRange

  IF NOT Keyword_Set( NORMAL) THEN $
	yPosRel = Double(yPos)/!d.y_size  $
  ELSE yPosRel = yPos

  oldTickLen = !p.ticklen
  IF ps  AND !d.y_size LT 10000 THEN $
	!p.ticklen =(10000 * 0.04 ) / !d.y_size

  FOR j = indexLow, i DO BEGIN
    idx = j-indexLow
    nTicksIdx = nTicks(idx) > 2
    tickVal = (FIndGen( nTicksIdx ) )*vals(j)/dilatation + offsets(idx)
    tickBars =  (FIndGen( nTicksIdx ) )*vals(j) + offsets(idx)

    ticks = FltArr( 3*nTicksIdx ) 

    nTIdxLst = IndGen( nTicksIdx )*3 + 1
    ticks( nTIdxLst  ) = !p.tickLen / (2-idx)

    xPlaces = !x.window(0) +tickBars*factor
    xPlaces = [ !x.window(0), xPlaces, xPlaces, xPlaces, !x.window(1) ]
    xPlaces = xPlaces( Sort( xPlaces ) )
    yPlaces = [0,sign*ticks,0] + yPosRel
    idxLst = Where( xPlaces LT !x.window(1) )
    IF Total( idxLst ) NE -1 THEN BEGIN
      xPlaces = xPlaces( idxLst )
      yPlaces = yPlaces( idxLst ) 
      Plots, xPlaces, yPlaces, /NORMAL   
    ENDIF

  ENDFOR

  !p.tickLen = oldTickLen
  IF noLabels THEN RETURN

  labels = tickVal 
  labelsPos = tickBars
  nbLabels = N_Elements( labels )

  WHILE ((nbLabels*11)*!d.x_ch_size*charSize GT rangeDev) AND $
	(nbLabels NE 2) DO BEGIN
     IF nbLabels GT 3 THEN BEGIN
       idxLst = Where( IndGen(nbLabels) MOD 2 EQ 0 )
       labels = labels( idxLst ) & labelsPos = labelsPos( idxLst )
       nbLabels = N_Elements( labels )
     ENDIF ELSE BEGIN
       IF  (nbLabels*11)*!d.x_ch_size GT rangeDev THEN BEGIN
          labels = [ labels(0), labels(1) ]
          labelsPos = [ labelsPos(0), labelsPos(1) ]
        ENDIF ELSE BEGIN
          labels = [ labels(0), labels(2) ]
          labelsPos = [ labelsPos(0), labelsPos(2) ]
        ENDELSE
        nbLabels = 2
      ENDELSE
   ENDWHILE

  charOffset = Float(!d.x_ch_size*charSize*4)/!d.x_size
  xPlaces = !x.window(0) + labelsPos(0)*factor - charOffset
  yPlaces = yPosRel - (sign GT 0)*$
	Float(!d.y_ch_size*charSize + 2*!p.charthick)/!d.y_size

  i = 0

  REPEAT BEGIN
    IF ( xPlaces GT !x.window(0)-0.1*!x.window(0) )  OR $
	 (ps AND ( xPlaces+charOffset LT $
	!x.window(0) +labelsPos((i+1)<(nbLabels-1))*factor- charOffset)) THEN BEGIN 
      IF dilatation EQ 1 THEN $
        XYOuts, xPlaces, yPlaces, $
	HMSConvert(labels(i)+axisRange(0), /ROUNDED), $
	/NORMAL, CHARSIZE = charSize $
      ELSE XYOuts, xPlaces, yPlaces, $
	HMSConvert(labels(i)+axisRange(0)), $
	/NORMAL, CHARSIZE = charSize
    ENDIF

    IF i LT nbLabels-1 THEN $
	xPlaces = !x.window(0) +labelsPos(i+1)*factor- charOffset
    i = i+1
  END UNTIL i EQ nbLabels OR $
	(xPlaces+2*charOffset GT $
	 !x.window(1)+0.1*!x.window(1)) 

END ; AxisTime
