;+
; NAME:
; 	CT_Handling
; PURPOSE:
;	User Interface to work with color tables. One can load
;	a system-defined color table, modify it, save it etc.
; CATEGORY
;	Image Processing
; CALLING SEQUENCE:
;	CT_Handling
; SIDE EFFECTS:
;	Windows and menus are opened. When a color table
;	is saved, a new file with extention ".ctb" is created.
;	The name is asked to the user.
;	If it is already present, the old one is deleted.
; RESTRICTION:
;	Works only on X-windows systems.
;
; MODIFICATION HISTORY:
; 	Created: 4/91, A.Csillaghy, Institute for Astronomy
;		ETH Zurich
;	Histogram Equalization added in October 92, A. Cs
;       IDL5/ssw/RagView version (IsIdl function eliminated) 3/98 ACs
;-

PRO Steps, nbSteps

  COMMON Colors, r, g, b, cr, cg, cb

  offset = !d.n_colors / (nbSteps-1)
  r = (IndGen( nbSteps )* offset) < 255
  g = (255 - IndGen( nbSteps )*102) > 0
  b = (255 - IndGen( nbSteps )*51) > 0

  r = Congrid1D( r, !d.n_colors, 1 )
  g = Congrid1D( g, !d.n_colors, 1 )
  b = Congrid1D( b, !d.n_colors, 1)

  r(0) = 0 & g(0) = 0 & b(0) = 0
  r(!d.n_colors-1) = 255 & g(!d.n_colors-1) = 255 
  b(!d.n_colors-1) = 255
  TvLct, r, g, b

END
  
PRO CT_Handling,  image

  COMMON Colors, r, g, b, cr, cg, cb

  IF !d.name NE 'X' THEN BEGIN
    Print,'Sorry, color handling is only provided on graphics terminals ...'
    RETURN
  ENDIF

  mainMenuLength = 9

  mainMenu = StrArr(mainMenuLength)

  mainMenu(0) = 'Color Table Handling: Choose Action or Exit'
  mainMenu(1) = 'Modify, Save/Load  customized color table... '
  mainMenu(2) = 'Load system color table ... '
  mainMenu(3) = 'Adjust color table ... '
  mainMenu(4) = 'Display color table'
  mainMenu(5) = 'Histogram Equalization of the Color Table'
  mainMenu(6) = 'Interactive Histogram Equalization ... '
  mainMenu(mainMenuLength-2) = 'Exit Color Table Handling'
  mainMenu(mainMenuLength-1) = 'Redisplay this Menu'

REPEAT  BEGIN

  choice  = WMenu( mainMenu, TITLE=0,INIT=1)

  CASE choice OF
    1: XPalette
    2: XLoadCt
    3: Rag_AdjCT
    4: XPalette
    5: Hist_Equal_CT, BytScl( image )
    6: Hist_Equal_Int, BytScl( image )
  ELSE:
  END

END UNTIL choice EQ mainMenuLength-2

IF StrMid(mainMenu(7),0,4) EQ 'Hide' THEN $
  Color_Palette,/DELETE

END
