PRO HistoFacility, y, length, XTITLE = xTitle

;+
; NAME: 
;	Histogram Facility
; PURPOSE:
;	Plots an histogram of the y-values
; CALLING SEQUENCE:
;	HistoFacility [, y [, length ] ]
; INPUT PARAMETERS:
;	y: the values to histogram, a 2D ( or 1D ) array
;	length: the number of relevant values per line in the
;		y-array. If not given, the histogram is
;		computed for all y-values.
; RESTRICTION:
;	Works also without parameters, but then it is assumed 
;	that the mdisp selection is active, and the plots values to
;	histogram will be loaded from the selection list.
; SIDE EFFECTS:
;	Opens a separate window
;	A PostScript or a sixel file can be created.
;
; MODIFICATION HISTORY
;	Created in March 92 on an idea from May 91
;	A.Csillaghy, Inst. of Astronomy, ETH Zurich
;	Sixel printing in Dec 92, A.Csillaghy
;-


  oldX = !x & oldY = !y & oldP = !p

  IF NoDefaults() THEN Init_Defaults
  GetPSSizes, xPos, yPos, xSize, ySize, landscape, colorOn

  IF NOT Keyword_Set( XTITLE ) THEN xTitle = !y.title

  IF N_Params() EQ 0 THEN BEGIN
    histoAll = 0
    nbSel = N_Selected()
    IF nbSel EQ 0 THEN BEGIN
      Print,'No plots selected'
      Print,''
      RETURN
    ENDIF
    LoadSelection, names, length, x, y
  ENDIF ELSE  IF N_Params() EQ 1 THEN histoAll = 1 $
  ELSE histoAll = 0

  IF histoAll EQ 1 THEN vector = y  $
  ELSE BEGIN
    i=0
    REPEAT BEGIN
      xTemp = x(0:length(i)-1, i)
      idxLst =Where( ( xTemp GE !x.crange(0)) AND $
	(xTemp LE !x.crange(1)))
      IF i EQ 0 THEN vector = y(idxLst, 0) $
      ELSE vector = [ vector, y( idxLst, i) ]
      i = i+1
    END UNTIL i EQ nbSel
  ENDELSE

  maximum = Round(  Max( vector, MIN = minimum ) )+1
  minimum = Round( minimum ) 
  std = StDev( vector, mean )
  Print, 'Histogram Facility '
  Print,'      Mean of the data sample: ', mean
  Print,'      Standard deviation of the sample: ', std

  binSize = 1

  winNr = !d.window + 1
  Window, winNr, TITLE = 'Histogram'

  menuLen = 7
  hMenu = StrArr( menuLen )

  hMenu(0) = 'Maximum = ' + StrTrim( maximum, 2 ) 
  hMenu(1) = 'Minimum = ' + StrTrim( minimum, 2 ) 
  hMenu(2) = 'Binsize = ' + StrTrim( binSize, 2 ) 
  hMenu(3) = 'Make MDisp File'
  hMenu(4) = 'Make Postscript File / Print ... '
  hMenu(5) = 'Exit Histogram Facility'
  hMenu(6) = 'Redisplay this Menu '

  choice = 0

  REPEAT BEGIN

    IF choice NE menuLen THEN BEGIN
      histo = Histogram(vector,MAX = maximum, $
	MIN = minimum, $
	BINSIZE = binSize )
      histo = [0,histo, 0]
      nHist = N_Elements(histo)
      xAxis = (FIndGen(nHist)-1)*binSize+ minimum
      Plot, xAxis, histo, XTITLE = xTitle, $
	YTITLE = 'Number of values, bin size = '+ $
	StrTrim( binSize, 2 ), XSTYLE = 3, YSTYLE = 2, $
	XRANGE = [0,0], YRANGE = [0,0], PSYM = 10
    ENDIF

    choice = General_Menu( hMenu, 'Histogram Facility: Select Option')

    CASE choice OF
      1: BEGIN
            Read_Test, 'Please enter the new maximum: ', maximum, tmp
            maximum = tmp
            hMenu(0) = 'Maximum = ' + StrTrim( maximum, 2 ) 
         END
      2: BEGIN
            Read_Test, 'Please enter the new minimum: ', minimum, tmp
            minimum = tmp
            hMenu(1) = 'Minimum = ' + StrTrim( minimum, 2 ) 
         END
      3: BEGIN
            Read_Test, 'Please enter the new bin size: ', binSize, tmp
            binSize = tmp
            hMenu(2) = 'Binsize = ' + StrTrim( binSize, 2 ) 
         END
      4: MDispWrite, xAxis, histo, FILENAME = 'histogram.mdisp'
      5: BEGIN
            oldDev = !d.name
            PrintInterface, status
              ext = 'ps'
              Set_Plot, 'PS'
              Device,FILE = 'enrad.'+ext, XOFFSET = xPos, $
	YOFFSET = yPos, XSIZE = xSize, YSIZE = ySize, $
	/PORTRAIT
            Plot, xAxis, histo, XTITLE = xTitle, $
	YTITLE =  'Number of values, bin size = '+ $
	StrTrim( binSize, 2 ), XSTYLE = 3, YSTYLE = 2, $
	XRANGE = [0,0], YRANGE = [0,0], PSYM = 10

            Device, /CLOSE
            Set_Plot, oldDev
            PrintInterface, status, /PRINT
          END
      ELSE:
    ENDCASE

  END UNTIL choice EQ menuLen-1

  WDelete, winNr
  !p = oldP & !x = oldX & !y = oldY

END
  
