PRO Load_User_CT,name, crP, cgP, cbP
;+
; NAME:
; 	Load_User_CT
; PURPOSE:
;	Read user defined color tables that have been
;	saved with the procedure "Save_User_CT"
; CATEGORY
;	Input/Output
; CALLING SEQUENCE:
;	Load_User_CT [, name] [, red, green, blue ]
; INPUT ARGUMENT:
;	name: the name of the file containing the table. If this
;		parameter is not present, the file to open 
;		will be asked interactively.
; OUTPUT ARGUMENTS:
;	red, green, blue: the vectors containing the new loaded
;		color table.
; COMMON BLOCK:
;	The block "Colors" is used to store the loaded table.
; SIDE EFFECT:
;	By reading interactively the file name, windows
;	are used.
; RESTRICTION:
;	Works only on graphics terminals.
;-
; MODIFICATION HISTORY:
;	Created: A.Csillaghy, 4/91

COMMON Colors, r,g,b,cr,cg,cb

IF !d.name NE 'X' THEN BEGIN
  Print,'This procedure works only on graphics screens ...'
  RETURN
ENDIF

nColors = !d.table_size

IF N_Elements(r) NE 0 THEN BEGIN
  red = 0B*r
  green=0B*g    ;initializations to the length of the color tables
  blue=0B*b
ENDIF ELSE BEGIN
  red = IndGen(nColors)
  green = red
  blue = red
ENDELSE


nParams = N_Params()
IF (nParams EQ 0) OR (nParams EQ 3 ) THEN BEGIN
  fileNames = FindFile('*.ctb')
  WHILE fileNames(0) EQ '' DO BEGIN
    choice=WMenu($
        ['No Color Tables in the current directory. Do you wish to:',$
	 'Change Directory','Abort'],$
	TITLE=0,INIT=1)
    IF choice EQ 2 THEN RETURN
    Clear_Screen
    Cd,CURRENT = dir
    Print,'Current directory is: ', dir
    Read,'Please give the new directory',dir
    fileNames = FindFile('*.ctb')
  ENDWHILE
  index = WMenu( ['Select Color Table', fileNames],TITLE=0)
ENDIF ELSE BEGIN
  fileNames = FindFile(name+'.ctb')
  IF fileNames(0) EQ '' THEN BEGIN
    winMsg = WMesg( ['Sorry, no shuch color table in this directory',$
	' ','Hit any key to continue'])
    HAK
    WDelete,winMsg
    RETURN
  ENDIF
  index = 1
ENDELSE

OpenR,unit,fileNames(index-1),/GET_LUN

ReadU, unit,red,green,blue
Free_LUn,unit

r = red & cr = red
g = green & cg = green
b = blue & cb = blue
TVLCT,red,green,blue

IF nParams EQ 3 THEN BEGIN
  name = red
  crP = green
  cgP = blue
ENDIF ELSE IF nParams EQ 4 THEN BEGIN
  crP = red
  cgP = green
  cbP = blue
ENDIF

RETURN 
END

