PRO Zoom_1D,dir, x0, x1, y0, y1, STATIC = static

;+
; NAME: 
;	Zoom_1D
; PURPOSE:
;	Gets interactively or statically (numbers read from the
;	keyboard) the minimum and maximum value
;	for the x or y range of a plot, and sets them.
; CATEGORY:
;	1D
; CALLING SEQUENCE:
;	Zoom_1D, dir [, xMin, xMax, yMin, yMax ]
; INPUT:
;	dir: The direction to zoom
; OUTPUTS:
;	xMin, xMax, yMin, yMax: The new limits of the plot
; KEYWORD:
;	/STATIC: If present, the zoom boundaries are 
;		entered on the terminal window.
; SIDE EFFECT:
;	On X terminals., windows are opened.
;
; MODIFICATION HISTORY:
;	Created by A.Csillaghy in May 1991, ETHZ
;	Modified for date/time in Nov. 92. A.Cs.
;-

dir = StrUpcase(dir)

IF dir EQ 'X' THEN hms = GetHMS() ELSE hms = 0

IF Keyword_Set(STATIC) THEN BEGIN

  Print,'Zoom in '+dir+' direction.'

  window = !x.window*(dir EQ 'X') + !y.window*(dir NE 'X')
  scale = !x.s*(dir EQ 'X') + !y.s*(dir NE 'X')


  lowDefault = (window(0) - scale(0) ) / scale(1)
  highDefault = (window(1) - scale(0) ) / scale(1)

  IF (dir EQ 'X' AND !x.type EQ 1) OR $
	 (dir EQ 'Y' AND !y.type EQ 1) THEN BEGIN
    lowdefault = 10^lowDefault
    highDefault = 10^highDefault
  ENDIF

  Read_Test,' Please insert the lowest '+dir+' value: ', lowDefault, $
	low, HMS = hms
  Read_Test,' Please insert the highest '+dir+' value: ', highDefault, $
	high, HMS = hms

  IF dir EQ 'X' THEN BEGIN
    !x.range = [low, high] 
  ENDIF ELSE !y.range = [low, high]

ENDIF ELSE BEGIN
    IF !d.name EQ 'X' THEN BEGIN
        plotWin = !d.window
        winNr = WMesg( 'Click to the lowest ' + dir+ '-cut' , $
                       'Zoom Plot', 500,200 )
        WSet, plotWin
        Cursor, x0, y0, /UP
        WDelete, winNr
 
        winNr = WMesg( 'Click to the highest ' + dir+ '-cut' , $
                       'Zoom Plot', 500,200 )
        WSet, plotWin
        Cursor, x1, y1, /UP
        WDelete, winNr
    ENDIF ELSE BEGIN
        Print, 'Move the cursor to the first '+ $
          dir + ' cut and press <Return>'
        IF !d.name NE 'TEK' THEN Cursor, x0, y0 $
        ELSE CursorVT, x0, y0
        Print,'Move the cursor to the second '+ $
          dir + ' cut and press <Return>'
        IF !d.name NE 'TEK' THEN Cursor, x1, y1 $
        ELSE CursorVT, x1, y1
    ENDELSE
    
    IF dir EQ 'X' THEN  !x.range = [x0,x1] $
    ELSE !y.range = [y0,y1]
    
ENDELSE
END
