PRO ASCII_Read,file, z, header, NX = nx, NY=ny

;+
; NAME: 
;	ASCII_Read
; PURPOSE:
;	Read ASCII formatted files, which contains a two-
;	dimaensionnal array of data with an optional header. 
;	The dimensions must be known and are asked to the user.
; CATEGORY:
;	Input/Output
; CALLING SEQUENCE:
;	ASCII_Read, filename, image [, header ]
; INPUT ARGUMENTS:
;	filename: the complete filename.
;	header: if present, a header is assumed to be in the file.
;	image: any variable of the type to read.
; KEYWORDS:
;	NX, NY: the dimensions of the data array. If not given,
;		they will be asked interactively.
; OUTPUT ARGUMENTS:
;	image: The data array read.
;	header: the file header.
; SIDE EFFECTS:
;	The terminal window is used to read the dimensions.
;-
; MODIFICATION HISTORY:
;	Created 4/91, A.Csillaghy

  On_IOError, ErrLabel

  Print,'ASCII File Read'
  nbPar = N_Params()
  OpenR,unit,file, /GET_LUN

  IF (nbPar EQ 3) THEN BEGIN
    Read_Test,'What is the number of header lines ',0,headerLines
    IF headerLines NE 0 THEN header = StrArr(headerLines)
  ENDIF ELSE headerLines = 0
  IF NOT Keyword_Set(NX)  THEN $
    Read,'Enter the number of data per block (x axis dimension): ',nx
  IF NOT Keyword_Set(NY) THEN $
    Read,'Enter the number of data blocks (y axis dimension): ',ny

  sizeZ=SIZE(z)
  CASE sizeZ(sizeZ(0)+1) OF
    0: z= FltArr(nx,ny)
    1: z= BytArr(nx,ny)
    2: z= IntArr(nx,ny)
    3: z= LongArr(nx,ny)
    4: z= FltArr(nx,ny)
    5: z= DblArr(nx,ny)
    6: z= ComplexArr(nx,ny)
    7: z= FltArr(nx,ny)
    8: z= FltArr(nx,ny)
  END

  IF headerLines NE 0 THEN begin
    Print, 'Reading the header ... '
    ReadF, unit, header
  ENDIF

  Print,' Now reading the data array ... '
  ReadF,unit,z
  Print,' The data range is [',MIN(z),'..',MAX(z),']'

  Free_LUn,unit

  RETURN

ErrLabel:
  Print, 'I/O Error encountered: '
  Print, !err_string

END
