PRO ASCII_Write, z, header, FILENAME = fileName, $
	INTERACTIVE = interactive

;+
; NAME:
; 	ASCII Write
; PURPOSE:
;	Writes an array in ASCII file with an optional header.
; CALLING SEQUENCE:
;	ASCII_Write, array [, header]
; INPUTS:
;	array: the array to write, may be of any dimension.
;	header: an optional header, an array of strings
; KEYWORDS;
;	FILENAME: for defining the name of the file. If not
;		present, the name of the file will be the
;		contents of the variable "!p.title" without
;		blanks, appended with {\it .dat}.
;	INTERACTIVE: if the "FILENAME" keyword is not
;		set the filename will be asked interactively
; SIDE EFFECT:
;	A file is written
; RESTRICTION:
;	The elements of the 2D array are written in the reverse
;	order as on the VAX VMS FORTRAN system. Namely, 
;	in WAVE, blocks of x coordinates are written.
; MODIFICATION HISTORY:
;	Created by A.Csillaghy in September 1991
;		Inst. of Astronomy, ETH Zurich
;       Modified March 98 for IDL5/ssw/ragview ACs.
;-

  Print,'ASCII File Write'

  IF NOT Keyword_Set( FILENAME ) THEN $
    IF Keyword_Set( INTERACTIVE ) THEN BEGIN
      fileName = ''
      Read,'Please enter the (complete) file name: ', fileName 
    ENDIF ELSE $
      fileName = StrCompress( !p.title, /REMOVE_ALL ) + '.dat'

  OpenW,unit,fileName, /GET_LUN

  IF N_Params() EQ 2 THEN PrintF, unit, header

  PrintF, unit, z
 
  Free_LUn, unit

END ; ASCII Write
