PRO Fortran_Read,file,z,par1,par2,par3
;+
; NAME: 
;	Fortran_Read
; PURPOSE:
;	Read Fortran unformatted files, which contains a two-
;	dimaensionnal array of data with an optional header. 
;	The dimensions must be known and asked to the user.
; CATEGORY:
;	Input/Output
; CALLING SEQUENCE:
;	Fortran_Read, filename, image [, nx, ny ] [, header ]
; INPUT ARGUMENTS:
;	filename: the complete filename.
;	nx, ny: the dimensions of the data array. If not given,
;		they will be asked interactively.
;	header: if present, a header is assumed to be in the file.
; OUTPUT ARGUMENTS:
;	image: The data array read.
;	header: the file header.
; SIDE EFFECTS:
;	The terminal window is used to read the dimensions.
;-
; MODIFICATION HISTORY:
;	Created 4/91, A.Csillaghy

Clear_Screen
Pto,20,5,'FORTRAN File Read' & Print,' ' & Print,' '

nbPar = N_Params(d)
Get_LUn,unit

IF (nbPar EQ 3) OR (nbPar EQ 5) THEN BEGIN
  Read,'What is the number of header lines ',headerLines
  header = StrArr(80,headerLines)
ENDIF
IF nbPar LE 3 THEN BEGIN
  Read,'What is the number of data per block (x axis dimension) ',xDim
  Read,'What is the number of data blocks (y axis dimension) ',yDim
ENDIF ELSE BEGIN 
  xDim=par1 & yDim=par2 
ENDELSE 

sizeZ=SIZE(z)
CASE sizeZ(sizeZ(0)+1) OF
  0: z= FltArr(xDim,yDim)
  1: z= FltArr(xDim,yDim)
  2: z= BytArr(xDim,yDim)
  4: z= IntArr(xDim,yDim)
  8: z= FltArr(xDim,yDim)
  16: z= LonArr(xDim,yDim)
  32: z= DblArr(xDim,yDim)
  64: z= ComplexArr(xDim,yDim)
END

Print,' '
Print,'Now reading the file ',file

IF (nbPar EQ 3) OR (nbPar EQ 5) THEN  BEGIN
  ReadF,unit,header
  CASE nbPar OF
    3: par1 = header
    5: par3 = header
  END
ENDIF

OpenR,unit,file+'/unformatted'
ForRd,unit,z
Close,unit
Free_LUn,unit

Print,'The data range is [',MIN(z),'..',MAX(z),']'

RETURN
END
