;+
; NAME:
;	HMS Conversion
; PURPOSE: 
;	Converts a floating number in a string with form:
;	'hh:mm:ss.ss'
; CALLING SEQUENCE:
;	result = HMSConvert( number )
; INPUT PARAMETER:
;	number: a scalar float value
; RESULT OF FUNCTION:
;	The created string
; KEYWORDS:
;	/ROUNDED: Return the rounded form 'hh:mm:ss'
;	/NOROUND: Returns the full form. (Default).
;
; MODIFICATION HISTORY:
;	Created by A.Csillaghy in 
;		Inst. of Astronomy, ETH Zurich
;	Seconds changed to format ss.sss (before: ss.ss )
;-

FUNCTION TStr, val

  IF val LT 10 THEN RETURN, '0'+ StrTrim( val, 2) $
  ELSE RETURN, StrTrim( val, 2 )

END ; TStr


FUNCTION HMSConvert, number, ROUNDED = rounded, $
	 NOROUND = noRound

  IF Keyword_Set( ROUNDED ) THEN nb = Round(number) $
  ELSE nb = number

  hours = Long(nb)/3600
  minutes = Long(nb)/60 - hours*60
  seconds =nb - hours*3600 - minutes*60 

  RETURN, TStr(hours) + ':' + TStr(minutes) + ':' + $
	StrMid(TStr( seconds ), 0, 6 )

END ; HMS Convert
   
