;+
; NAME:
;	MDisp
; PURPOSE:
;	Plot system to analyse and review astronomical
;	one-dimensional data. It is a user interface intended
;	for people who doesnt know anything about PV-WAVE.
; CATEGORY:
;	User Interface
; CALLING SEQUENCE:
;	MDisp
; KEYWORD:
; 	/RESET: Initialize the plot table and the selectioner,
;		so that the plots present in both are erased.
; SIDE EFFECT:
;	Open windows and use the terminal window.
; RESTRICTIONS
;	Works only in interactive mode;
;	Does not work on VT-100 terminals.
;
; MODIFICATION HISTORY:
;	Created in June 1991 A.Csillaghy
;-

PRO RWVariables, SAVE = save, RESTORE = restore

COMMON TextRetrieval, v10
COMMON OverallVars, v1,v2,v3,v4,v5,v6,v7
COMMON PSVars, v20, v21, v22, v23, v24, v25, v26
COMMON SelectionRetrieval, v11
COMMON Data, v13, v14

IF Keyword_Set(SAVE) THEN $
  Save,/ALL,FILENAME = 'mdispsave.dat'
IF Keyword_Set(RESTORE) THEN $
  Restore, FILENAME = 'mdispsave.dat'

END


PRO Read_And_Store, FILENAME = fileName, NEWSEL = newSel

  Files_1D, x, y, qualifier, dx, dy, fName, $
	LINESTYLE = lineStyle, THICK = thick, $
	COLOR = color, SUBTITLE = subTitle, $
	TITLE = title, XTITLE = xTitle, YTITLE = yTitle, $
	TEXT = text, STATUS = status, USERSYM = userSym, $
	FILENAME = fileName

  IF status EQ 'Done' THEN BEGIN
    PutTitles, title, xTitle, yTitle, subTitle
    
    nQual = N_Elements( qualifier )
    IF nQual GT 0 THEN BEGIN 
      IF N_Elements( VectCmp( qualifier, 'EQ' )) EQ nQual-1 THEN $
        overallQual = qualifier(0) $
      ELSE overallQual = 0
    END ELSE overallQual = 0

    InsertPlot, fName, N_Elements(x), x, y, qualifier, dx, dy, $
	color, lineStyle, thick, offset, overallQual, userSym, $
	title, xTitle, yTitle, subtitle, text, /NEW

    IF Keyword_Set( NEWSEL ) THEN InitSel
    InsertSel, fName
  ENDIF

END ; Read and store


PRO MDisp, RESET = reset, FILENAME = fileName

 oldQuiet = !quiet
 !quiet = 1
 oldHMS = GetHMS()

 IF !d.name EQ 'X' THEN BEGIN
    Window, XSIZE = 750, YSIZE = 600, TITLE = ' MDisp Window ' 
 ENDIF ELSE IF !d.name EQ 'TEK' THEN EraseVT $
 ELSE Erase
 IF No_Data() OR Keyword_Set(RESET) THEN Init_Data 

  mainMenuLength = 9
  mainMenu = StrArr(mainMenuLength)

  mainMenu(0) = 'Files ... '
  mainMenu(1) = 'Clear and New File ... '
  mainMenu(2) = 'Data Display ... '
  mainMenu(3) = 'Modify Data  ... '
  mainMenu(4) = 'Customize ... '
  mainMenu(5) = 'Plots Selection ... '
  mainMenu(6) = 'Store the Session and EXIT'
  mainMenu(7) = 'EXIT without Store'
  mainMenu(8) = 'Redisplay this Menu'

  !x.style = 1 & !y.style = 1

  file = FindFile('mdispsave.dat')
  IF  file(0) EQ 'mdispsave.dat' THEN BEGIN
    choice = General_Menu( ['yes', 'no' ], $
	'Do you want to restore from the last session ?' )
    IF choice EQ 1 THEN RWVariables,/RESTORE
  ENDIF

  IF No_Data() THEN Read_And_Store, FILENAME = fileName
  IF Keyword_Set( FILENAME ) THEN Display_1D $
  ELSE BEGIN 
    !x.range = [0,0] & !y.range = [0,0] 
  END
  choice = 0
  
  REPEAT BEGIN 

  choice = General_Menu(mainMenu,'MDisp: Main Menu')

  CASE choice OF
    1: Read_And_Store
    2: Read_And_Store, /NEWSEL
    3: Display_1D
    4: Modify_1d
    5: Customize_1D
    6: Plots_Selection
    7: RWVariables, /SAVE 
  ELSE:
  ENDCASE
  IF !d.name EQ 'X' AND choice LE 2 THEN $
	Data_Display,  RESET = choice EQ 2, /MDISP
  
END UNTIL (choice EQ mainMenuLength - 2) OR $
	(choice EQ mainMenuLength -1)

IF !d.window NE -1 THEN WDelete
Clear_Screen
!quiet = oldQuiet
PutHMS, oldHMS

END
