PRO RAGView, FILENAME = fileName, NOERASE = noerase

;+
; NAME:
;	RAG View
; PURPOSE:
;	Ragview is an image processing system specially 
; 	developed for the analysis of solar radio spectrograms/.
; CALLING SEQUENCE:
;	RagView
; COMMON BLOCKS:
;	ImageReal, image, xAxis, yAxis, fName: 
;		contains the 2D image,
;		in its original data type, 
;		the x-axis and the y-axis values and the file 
;		name.
;	Boundaries, xMin, xMax, yMin, yMax: these four
;		parameters are used for limiting the
;		pixel ranges displayed, and are used with
;		several procedures called by RagView.
;	These common blocks are only used in this program.
;	The related procedures do not use them. They are
;	here to provide the possibility to use data outside
;	of ragview.
; SIDE EFFECTS:
;	RagView opens a lot of windows and creates files, dependent
;	of the user's choices.
; RESTRICTIONS:
;	Works only in interactive mode.
; MODIFICATION HISTORY:
;	Created: (4/91)  (under the name of enrad) A.Csillaghy 
;		       Institute for Astronomy, ETH Zurich
;	Window+Selection Management added in August 1991, Cs.
;	NOERASE keyword in June, 93
;	titles kept even outside the session, Nov 93, A.cs
;	IDL transformations Jan 95 ACs
; 	SSW adaptation, renamed from enrad to ragview,
;       IDL 5 version March 1998 ACs
;-

  COMMON ImageReal, zReal,xAxis,yAxis, fName ; Data
  COMMON Boundaries, xMin, xMax, yMin, yMax ; in Pixels
  COMMON Colors, r, g, b, rr, gg, bb
  COMMON Selection2D, images, wNr, nbTemps, nbWMax, dir

  oldQuiet = !quiet
;  !quiet = 1
  !x.type = 0 & !y.type = 0
  IF !x.charsize EQ 0 THEN  !x.charsize=1.0
  IF !y.charsize EQ 0 THEN  !y.charsize=1.0
  IF !p.charsize EQ 0 THEN  !p.charsize=1.0


  IF Keyword_Set( FILENAME ) THEN fName = fileName

  IF N_Elements(images) EQ 0  THEN Init_Display
  Init_Selection
  defaults = FindFile( '.enrad')
  IF defaults(0) EQ '.enrad' THEN Settings, /RESTORE

  mainMenuLength = 10
  mainMenu = StrArr(mainMenuLength)

  mainMenu(0) = 'Files ... '
  mainMenu(1) = 'Image Display ...'
  mainMenu(2) = 'Modify Image ...'
  mainMenu(3) = 'Customize ... '
  mainMenu(4) = 'X-Plot(s) (access to mdisp) ... '
  mainMenu(5) = 'Y-Plot(s) (access to mdisp) ... '
  mainMenu(6) = 'Windows + Selection Management ... '
  mainMenu(7) = 'Store Session and Exit'
  mainMenu(8) = 'Exit without Store'
  mainMenu(9) = 'Redisplay this Menu'

  IF NOT Keyword_Set( FILENAME ) THEN BEGIN
    file = FindFile('enradsave.dat')
    IF  file(0) EQ 'enradsave.dat' THEN BEGIN
      choice = General_Menu( ['yes', 'no' ], $
	'Do you want to restore from the last ENRAD session ?' )
      IF choice EQ 1 THEN BEGIN
        Restore,'enradsave.dat'
        IF N_Elements(r) NE 0 THEN TvLCT, rr,gg,bb
      ENDIF
    ENDIF
  ENDIF

  status = 'Not Read'
  IF N_Elements(zReal) EQ 0 OR N_Elements(yMax) EQ 0 $
	 OR Keyword_Set( FILENAME ) THEN BEGIN
    IF Keyword_Set ( FILENAME ) THEN $
      Files_Handling,zReal,xAxis,yAxis, fileName, STATUS = status, $
	FILENAME = fName, /SIZES_ON $
	; the other things read are
	; stored in the system variables.
    ELSE Files_Handling,zReal,xAxis,yAxis, STATUS = status, $
	FILENAME = fName, /SIZES_ON
    xMin = 0 & xMax = N_Elements(xAxis)-1
    yMin = 0 & yMax = N_Elements(yAxis)-1
  ENDIF ELSE status = "Read"

  plot, indgen(10), /nodata, ys=4, xs=4, tit='' ; to establish the coord. system
  IF !d.name EQ 'X' AND N_Elements(r) EQ 0 THEN $
	LoadCT, 39, /SILENT

  IF status EQ "Read"  THEN BEGIN
    FileBreak, fName, FILE = fName
    IF (!d.name EQ 'X')  THEN BEGIN
      Show_Image,zReal( xMin: xMax, yMin: yMax ), $
	xAxis( xMin: xMax ), yAxis( yMin: yMax ), /SIZES_ON, $
	WINNR = GetWNr()
      Image_Info,zReal( xMin: xMax, yMin: yMax ), $
	xAxis( xMin: xMax ), yAxis( yMin: yMax ), FILE=fName
      Put_Selection, zReal, xAxis, yAxis, xMin, xMax, yMin, yMax, $
	FILESTATE = "permanent", FNAME = fName
    ENDIF
  ENDIF

  choice = 0
     
  REPEAT BEGIN 

    choice = General_Menu(mainMenu,'RagView: Main Menu')

    CASE choice OF
      1: BEGIN
          Files_Handling,zReal,xAxis,yAxis,  $ 		
            STATUS = status, FILENAME = fName, $
            BOUNDARY = [xMin, xMax, yMin, yMax ], $
            /SIZES_ON
          IF STATUS EQ "Read"  THEN BEGIN
               Show_Image,zReal,xAxis,yAxis, WINNR = GetWNr(), /SIZES_ON
               Image_Info,zReal,xAxis,yAxis, FILE = fName
               xMin = 0 & xMax = N_Elements(xAxis)-1
               yMin = 0 & yMax = N_Elements(yAxis)-1
               Put_Selection, zReal, xAxis, yAxis, xMin, xMax, yMin, $
	yMax,FILESTATE = "permanent", FNAME = fName
             ENDIF 
           END
      2: IF N_Elements(zReal) GT 1 THEN $
            Display_2D, zReal,xAxis, yAxis, $
	xMin, xMax, $
	yMin, yMax, TITLE = fName, $
	/SIZES_ON, /SELECTION_ON
      3: Modify, zReal, xAxis, yAxis, xMin, xMax, yMin, yMax, fName
      4: Custom_2D
      5: BEGIN
            xVar = !x & yVar = !y & zVar = !z
            RagView_MDisp_Int, zReal(xMin:xMax, yMin:yMax), $,
  	xAxis(xMin:xMax), $
	yAxis(yMin:yMax), !x.title, /RESET, TITLE = !p.title
            MDisp
            !x = xVar & !y = yVar & !z = zVar
             Image_Info, zReal(xMin:xMax, yMin:yMax), $
	xAxis( xMin: xMax ), yAxis( yMin: yMax ), FILE=title
          END
      6: BEGIN
            xVar = !x & yVar = !y & zVar = !z & pVar = !p
            hms = GetHMS()
            Enrad_MDisp_Int, $
	Transpose( zReal(xMin:xMax, yMin:yMax) ), $
	yAxis(yMin: yMax), xAxis(xMin: xMax), !y.title, $
	 /RESET, /YDIR, TITLE = title
            MDisp
            PutHMS, hms
            !x = xVar & !y = yVar & !z = zVar & !p = pVar
             Image_Info, zReal(xMin:xMax, yMin:yMax), $
	xAxis( xMin:xMax ), yAxis( yMin: yMax ), FILE=title
          END
      7: BEGIN
             Window_Management, zReal, xAxis, yAxis, $
	xMin, xMax, yMin, yMax, STATUS = status, $
	FNAME = fName
             IF status EQ "Done" THEN BEGIN
               Image_Info, zReal(xMin:xMax, yMin:yMax), $
	xAxis( xMin:xMax ), yAxis( yMin: yMax ), FILE=title
             ENDIF
           END
      8:  Save, /COMM, /VARIABLES, $
	FILENAME='enradsave.dat'
    ELSE:
    ENDCASE
  
  END UNTIL (choice GE mainMenuLength-2) AND $
	(choice LT mainMenuLength)

  IF NOT Keyword_Set( NOERASE ) THEN $
    WHILE !d.window NE -1 DO WDelete
  IF (choice LT mainMenuLength) AND $
	(choice GE mainMenuLength-2) THEN $
	Sel_Del,/ALL, /DIR

  !quiet = oldQuiet

END
