FUNCTION ConstBackSub, image, min, max, direction, $
	BACKGROUND = background, $
	AUTOMATIC = automatic, BKGARR = bkgArr

;+ 
; PURPOSE: 
;	Computes the mean background out ouf a defined
;	set of neighbouring profiles and subtracts it.
; CALLING SEQUENCE:
;	result = ConstBackSub( image, min, max [, direction ] )
; INPUTS:
;	image: 2D array
;	min, max: pixel number of beginning and end of the
;		background region, respectively
;	direction: 'X' or 'Y'
; KEYWORDS:
;	BACKGROUND: to get the background array subtracted
;	AUTOMATIC: the background array to subtract is
;		searched automatically by taking some vectors
;		in the image with lowest mean and lowest
;		variance as background vectors. If a number is
;		passed it is taken as percet of channels to 
;		consider else the default is 5 %.
;	BKGARR: the background field computed by the AUTOMATIC proc.
; PROCEDURE:
;	Between min and max, the values are averaged in
;	X or Y, and the resulting vector is subtracted from the
;	original image.
; SIDE EFFECT:
;	The image is returned as FLOAT type.
; MODIFICATION HISTORY:
;	Created in August 1991 by A.Csillaghy,
;		Inst. of Astronomy, ETH Zurich
;	AUTOMATIC in july 93, A.Cs
;	BKGARR in Jan 94, A.Cs.
;-

  IF N_Elements(direction) EQ 0 THEN direction = 'X'
  IF direction EQ 'X' THEN im = Double(image) $
  ELSE im = Double(Transpose(image))

  nx = N_Elements( im(*,0))
  ny = N_Elements( im(0,*))

  IF Keyword_Set( AUTOMATIC ) THEN BEGIN

    average = Avg( im, 1 ) 
;    average = average - Min( average ) 
;    average = average / Max( average )
    sig = Sigma( im,1,1 ) 
    sig( Where( NOT Finite( sig ) ) ) = Max( sig )
    
 ;   sig = sig - Min( sig )
;    sig = sig / Max( sig )
    both = BytScl(average) + Fix( BytScl(sig) )

    list  = Sort( both )
    IF automatic EQ 1 THEN automatic = 0.05
    nPart = (N_Elements( list )*automatic) < ( nx-1) > 0
    list = list( 0: nPart )    
  ENDIF ELSE BEGIN
    min = min > 0 < (nx-1) 
    max = max > 0 < (nx-1)
    list = LIndGen( max-min ) + min
  ENDELSE

  bkgArr = im( list, * )
  background = Avg( bkgArr, 0 ) 

  FOR i = 0L, nx-1 DO im(i,*) = im(i,*) - background

  IF direction EQ 'X' THEN RETURN, im $
  ELSE RETURN, Transpose( im )

END
